# log12

Log12 unifies observability through handling of quantitative metrics, distributed tracing and qualitative message logging in a single and self-contained structured logging library that follows the [12-factor logging recommendation](https://12factor.net/logs) to see logs as a stream of events written that shall be written simply to `stdout`.